parameters
==========

A generic package for capturing and validating user parameters

[![Build Status](https://travis-ci.org/inasafe/parameters.svg?branch=master)](https://travis-ci.org/inasafe/parameters)

[![Coverage Status](https://coveralls.io/repos/inasafe/parameters/badge.svg)](https://coveralls.io/r/inasafe/parameters)